All of lore.kernel.org
 help / color / mirror / Atom feed
From: Chris Wilson <chris@chris-wilson.co.uk>
To: intel-gfx@lists.freedesktop.org
Cc: Daniel Vetter <daniel.vetter@ffwll.ch>, dri-devel@lists.freedesktop.org
Subject: [PATCH 01/11] drm: Export drm_dev_init() for subclassing
Date: Fri, 27 May 2016 15:00:34 +0100	[thread overview]
Message-ID: <1464357644-16775-2-git-send-email-chris@chris-wilson.co.uk> (raw)
In-Reply-To: <1464357644-16775-1-git-send-email-chris@chris-wilson.co.uk>

In order to allow drivers to pack their privates and drm_device into one
struct (e.g. for subclassing), export the initialisation routines for
struct drm_device.

Signed-off-by: Chris Wilson <chris@chris-wilson.co.uk>
Cc: Daniel Vetter <daniel.vetter@ffwll.ch>
Cc: dri-devel@lists.freedesktop.org
---
 drivers/gpu/drm/drm_drv.c | 63 ++++++++++++++++++++++++++++++++++++-----------
 include/drm/drmP.h        |  3 +++
 2 files changed, 52 insertions(+), 14 deletions(-)

diff --git a/include/drm/drmP.h b/include/drm/drmP.h
index c5d29505f937..12dc5f9cad89 100644
--- a/include/drm/drmP.h
+++ b/include/drm/drmP.h
@@ -1075,6 +1075,9 @@ extern void drm_sysfs_hotplug_event(struct drm_device *dev);
 
 struct drm_device *drm_dev_alloc(struct drm_driver *driver,
 				 struct device *parent);
+int drm_dev_init(struct drm_device *dev,
+		 struct drm_driver *driver,
+		 struct device *parent);
 void drm_dev_ref(struct drm_device *dev);
 void drm_dev_unref(struct drm_device *dev);
 int drm_dev_register(struct drm_device *dev, unsigned long flags);
diff --git a/drivers/gpu/drm/drm_drv.c b/drivers/gpu/drm/drm_drv.c
index bff89226a344..ceb85e611a07 100644
--- a/drivers/gpu/drm/drm_drv.c
+++ b/drivers/gpu/drm/drm_drv.c
@@ -549,11 +549,12 @@ static void drm_fs_inode_free(struct inode *inode)
 }
 
 /**
  * drm_dev_alloc - Allocate new DRM device
  * @driver: DRM driver to allocate device for
  * @parent: Parent device object
  *
- * Allocate and initialize a new DRM device. No device registration is done.
+ * Initialize a new DRM device. No device registration is done.
  * Call drm_dev_register() to advertice the device to user space and register it
  * with other core subsystems. This should be done last in the device
  * initialization sequence to make sure userspace can't access an inconsistent
@@ -565,18 +566,14 @@ static void drm_fs_inode_free(struct inode *inode)
  * Note that for purely virtual devices @parent can be NULL.
  *
  * RETURNS:
- * Pointer to new DRM device, or NULL if out of memory.
+ * 0 on success, or error code on failure.
  */
-struct drm_device *drm_dev_alloc(struct drm_driver *driver,
-				 struct device *parent)
+int drm_dev_init(struct drm_device *dev,
+		 struct drm_driver *driver,
+		 struct device *parent)
 {
-	struct drm_device *dev;
 	int ret;
 
-	dev = kzalloc(sizeof(*dev), GFP_KERNEL);
-	if (!dev)
-		return NULL;
-
 	kref_init(&dev->ref);
 	dev->dev = parent;
 	dev->driver = driver;
@@ -638,7 +635,7 @@ struct drm_device *drm_dev_alloc(struct drm_driver *driver,
 			goto err_setunique;
 	}
 
-	return dev;
+	return 0;
 
 err_setunique:
 	if (drm_core_check_feature(dev, DRIVER_GEM))
@@ -653,8 +650,46 @@ err_minors:
 	drm_fs_inode_free(dev->anon_inode);
 err_free:
 	mutex_destroy(&dev->master_mutex);
-	kfree(dev);
-	return NULL;
+	return 0;
+}
+EXPORT_SYMBOL(drm_dev_init);
+
+/**
+ * drm_dev_alloc - Allocate new DRM device
+ * @driver: DRM driver to allocate device for
+ * @parent: Parent device object
+ *
+ * Allocate and initialize a new DRM device. No device registration is done.
+ * Call drm_dev_register() to advertice the device to user space and register it
+ * with other core subsystems. This should be done last in the device
+ * initialization sequence to make sure userspace can't access an inconsistent
+ * state.
+ *
+ * The initial ref-count of the object is 1. Use drm_dev_ref() and
+ * drm_dev_unref() to take and drop further ref-counts.
+ *
+ * Note that for purely virtual devices @parent can be NULL.
+ *
+ * RETURNS:
+ * Pointer to new DRM device, or NULL if out of memory.
+ */
+struct drm_device *drm_dev_alloc(struct drm_driver *driver,
+				 struct device *parent)
+{
+	struct drm_device *dev;
+	int ret;
+
+	dev = kzalloc(sizeof(*dev), GFP_KERNEL);
+	if (!dev)
+		return NULL;
+
+	ret = drm_dev_init(dev, driver, parent);
+	if (ret) {
+		kfree(dev);
+		return NULL;
+	}
+
+	return dev;
 }
 EXPORT_SYMBOL(drm_dev_alloc);
 
@@ -549,11 +549,12 @@ static void drm_fs_inode_free(struct inode *inode)
 
 /**
- * drm_dev_alloc - Allocate new DRM device
- * @driver: DRM driver to allocate device for
+ * drm_dev_init - Initialise new DRM device
+ * @dev: DRM device
+ * @driver: DRM driver
  * @parent: Parent device object
  *
-- 
2.8.1

_______________________________________________
dri-devel mailing list
dri-devel@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/dri-devel

  reply	other threads:[~2016-05-27 14:00 UTC|newest]

Thread overview: 28+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2016-05-27 14:00 Reordering debugfs registration vs driver loading Chris Wilson
2016-05-27 14:00 ` Chris Wilson [this message]
2016-05-27 15:29   ` [PATCH 01/11] drm: Export drm_dev_init() for subclassing Nils Wallménius
2016-05-27 15:36     ` Chris Wilson
2016-05-27 15:54       ` Emil Velikov
2016-05-27 16:08         ` [Intel-gfx] " Chris Wilson
2016-05-27 16:11           ` Emil Velikov
2016-05-27 14:00 ` [PATCH 02/11] drm: Add a callback from connector registering Chris Wilson
2016-05-30  8:49   ` Daniel Vetter
2016-05-30  8:57     ` Chris Wilson
2016-05-27 14:00 ` [PATCH 03/11] drm/i915: Perform async fbdev initialisation much later Chris Wilson
2016-05-27 14:00 ` [PATCH 04/11] drm/i915: Move connector registration to driver registration phase Chris Wilson
2016-05-27 14:00 ` [PATCH 05/11] drm/i915: Register debugfs interface last Chris Wilson
2016-05-27 14:00 ` [PATCH 06/11] drm/i915: Demidlayer driver loading Chris Wilson
2016-05-27 14:00 ` [PATCH 07/11] drm/i915: Demidlayer driver unloading Chris Wilson
2016-05-27 14:00 ` [PATCH 08/11] drm/i915: Start exploiting drm_device subclassing Chris Wilson
2016-05-27 14:15   ` Tvrtko Ursulin
2016-05-27 14:46     ` [PATCH] drm/i915: Remove drm_i915_private->dev backpointer Chris Wilson
2016-05-30  6:58       ` Joonas Lahtinen
2016-05-30  8:21         ` Chris Wilson
2016-05-27 14:00 ` [PATCH 09/11] drm/i915: Merge i915_dma.c into i915_drv.c Chris Wilson
2016-05-30  6:30   ` Joonas Lahtinen
2016-05-27 14:00 ` [PATCH 10/11] drm/i915: Split out the PCI driver interface to i915_pci.c Chris Wilson
2016-05-30  6:36   ` Joonas Lahtinen
2016-05-27 14:00 ` [PATCH 11/11] drm/i915: Move module init/exit " Chris Wilson
2016-05-30  6:44   ` Joonas Lahtinen
2016-05-30  7:55     ` Chris Wilson
2016-05-27 14:58 ` ✗ Ro.CI.BAT: failure for series starting with [01/11] drm: Export drm_dev_init() for subclassing (rev2) Patchwork

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1464357644-16775-2-git-send-email-chris@chris-wilson.co.uk \
    --to=chris@chris-wilson.co.uk \
    --cc=daniel.vetter@ffwll.ch \
    --cc=dri-devel@lists.freedesktop.org \
    --cc=intel-gfx@lists.freedesktop.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.